{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 10000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": "copynumber_tm.batchdiff_cfdna.R",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "either 'FULL' or 'MIN'",
                    "id": "#copynumber.cwl/do_full"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "normal_ALL_intervalnomapqcoverage_loess.txt",
                    "id": "#copynumber.cwl/loess_normals"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "tumor_ALL_intervalnomapqcoverage_loess.txt",
                    "id": "#copynumber.cwl/loess_tumors"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "e.g. ACCESSv1-VAL-20180001",
                    "id": "#copynumber.cwl/project_name_cnv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "ACCESS_targets_coverage.txt Full Path to text file of target annotations. Columns = (Chrom, Start, End, Target, GC_150bp, GeneExon, Cyt, Interval)",
                    "id": "#copynumber.cwl/targets_coverage_annotation"
                }
            ],
            "id": "#copynumber.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('*copynumber_segclusp.pdf')"
                    },
                    "id": "#copynumber.cwl/copy_pdf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('*copynumber_segclusp.genes.txt')"
                    },
                    "id": "#copynumber.cwl/genes_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('*copynumber_segclusp.intragenic.txt')"
                    },
                    "id": "#copynumber.cwl/intragenic_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('*copynumber_segclusp.probes.txt')"
                    },
                    "id": "#copynumber.cwl/probes_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$('*.seg')"
                    },
                    "id": "#copynumber.cwl/seg_files"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 8,
                    "ramMin": 10000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": "cfdna_scna",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--normalManifest"
                    },
                    "doc": "normal_manifest.txt Full path to the normal sample manifest, tab serparated BAM path, patient sex",
                    "id": "#coverage.cwl/normal_sample_list"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--runID"
                    },
                    "doc": "e.g. ACCESSv1-VAL-20180001",
                    "id": "#coverage.cwl/project_name_cnv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--genomeReference"
                    },
                    "doc": "Homo_Sapeins_hg19.fasta Full Path to the reference fasta file",
                    "id": "#coverage.cwl/reference_fasta"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bedTargets"
                    },
                    "doc": "ACCESS_targets_coverage.bed Full Path to BED file of panel targets",
                    "id": "#coverage.cwl/targets_coverage_bed"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--threads"
                    },
                    "doc": "Number of Threads to be used to generate coverage metrics",
                    "id": "#coverage.cwl/threads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--tumorManifest"
                    },
                    "doc": "tumor_manifest.txt Full path to the tumor sample manifest, tab serparated BAM path, patient sex",
                    "id": "#coverage.cwl/tumor_sample_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$('*_bams.list')"
                    },
                    "id": "#coverage.cwl/bam_list"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('*normals_targets_nomapq.covg_interval_summary')"
                    },
                    "id": "#coverage.cwl/normals_covg"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('*tumors_targets_nomapq.covg_interval_summary')"
                    },
                    "id": "#coverage.cwl/tumors_covg"
                }
            ],
            "id": "#coverage.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 10000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": "loessnormalize_nomapq_cfdna.R",
            "arguments": [
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "coverage files, targets_nomapq.covg_interval_summary",
                    "id": "#loess.cwl/coverage_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "e.g. ACCESSv1-VAL-20180001",
                    "id": "#loess.cwl/project_name_cnv"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "tumor or normal",
                    "id": "#loess.cwl/run_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "ACCESS_targets_coverage.txt Full Path to text file of target annotations. Columns = (Chrom, Start, End, Target, GC_150bp, GeneExon, Cyt, Interval)",
                    "id": "#loess.cwl/targets_coverage_annotation"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('*_loessnorm.pdf')"
                    },
                    "id": "#loess.cwl/loess_pdf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('*_ALL_intervalnomapqcoverage_loess.txt')"
                    },
                    "id": "#loess.cwl/loess_text"
                }
            ],
            "id": "#loess.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/normal_sample_list"
                },
                {
                    "type": "string",
                    "id": "#main/project_name"
                },
                {
                    "type": "File",
                    "id": "#main/reference_fasta"
                },
                {
                    "type": "File",
                    "id": "#main/targets_coverage_annotation"
                },
                {
                    "type": "File",
                    "id": "#main/targets_coverage_bed"
                },
                {
                    "type": "int",
                    "id": "#main/threads"
                },
                {
                    "type": "File",
                    "id": "#main/tumor_sample_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/coverage/bam_list",
                    "id": "#main/bam_list"
                },
                {
                    "type": "File",
                    "outputSource": "#main/copy_number/copy_pdf",
                    "id": "#main/copy_pdf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/copy_number/genes_file",
                    "id": "#main/genes_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/copy_number/intragenic_file",
                    "id": "#main/intragenic_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/loess_normal/loess_pdf",
                    "id": "#main/normal_loess_pdf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/loess_normal/loess_text",
                    "id": "#main/normal_loess_text"
                },
                {
                    "type": "File",
                    "outputSource": "#main/coverage/normals_covg",
                    "id": "#main/normals_covg"
                },
                {
                    "type": "File",
                    "outputSource": "#main/copy_number/probes_file",
                    "id": "#main/probes_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/copy_number/seg_files",
                    "id": "#main/seg_files"
                },
                {
                    "type": "File",
                    "outputSource": "#main/loess_tumor/loess_pdf",
                    "id": "#main/tumor_loess_pdf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/loess_tumor/loess_text",
                    "id": "#main/tumor_loess_text"
                },
                {
                    "type": "File",
                    "outputSource": "#main/coverage/tumors_covg",
                    "id": "#main/tumors_covg"
                }
            ],
            "steps": [
                {
                    "run": "#copynumber.cwl",
                    "in": [
                        {
                            "default": "MIN",
                            "id": "#main/copy_number/do_full"
                        },
                        {
                            "source": "#main/loess_normal/loess_text",
                            "id": "#main/copy_number/loess_normals"
                        },
                        {
                            "source": "#main/loess_tumor/loess_text",
                            "id": "#main/copy_number/loess_tumors"
                        },
                        {
                            "source": "#main/project_name",
                            "id": "#main/copy_number/project_name_cnv"
                        },
                        {
                            "source": "#main/targets_coverage_annotation",
                            "id": "#main/copy_number/targets_coverage_annotation"
                        }
                    ],
                    "out": [
                        "#main/copy_number/genes_file",
                        "#main/copy_number/probes_file",
                        "#main/copy_number/copy_pdf",
                        "#main/copy_number/intragenic_file",
                        "#main/copy_number/seg_files"
                    ],
                    "id": "#main/copy_number"
                },
                {
                    "run": "#coverage.cwl",
                    "in": [
                        {
                            "source": "#main/normal_sample_list",
                            "id": "#main/coverage/normal_sample_list"
                        },
                        {
                            "source": "#main/project_name",
                            "id": "#main/coverage/project_name_cnv"
                        },
                        {
                            "source": "#main/reference_fasta",
                            "id": "#main/coverage/reference_fasta"
                        },
                        {
                            "source": "#main/targets_coverage_bed",
                            "id": "#main/coverage/targets_coverage_bed"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/coverage/threads"
                        },
                        {
                            "source": "#main/tumor_sample_list",
                            "id": "#main/coverage/tumor_sample_list"
                        }
                    ],
                    "out": [
                        "#main/coverage/tumors_covg",
                        "#main/coverage/normals_covg",
                        "#main/coverage/bam_list"
                    ],
                    "id": "#main/coverage"
                },
                {
                    "run": "#loess.cwl",
                    "in": [
                        {
                            "source": "#main/coverage/normals_covg",
                            "id": "#main/loess_normal/coverage_file"
                        },
                        {
                            "source": "#main/project_name",
                            "id": "#main/loess_normal/project_name_cnv"
                        },
                        {
                            "default": "normal",
                            "id": "#main/loess_normal/run_type"
                        },
                        {
                            "source": "#main/targets_coverage_annotation",
                            "id": "#main/loess_normal/targets_coverage_annotation"
                        }
                    ],
                    "out": [
                        "#main/loess_normal/loess_text",
                        "#main/loess_normal/loess_pdf"
                    ],
                    "id": "#main/loess_normal"
                },
                {
                    "run": "#loess.cwl",
                    "in": [
                        {
                            "source": "#main/coverage/tumors_covg",
                            "id": "#main/loess_tumor/coverage_file"
                        },
                        {
                            "source": "#main/project_name",
                            "id": "#main/loess_tumor/project_name_cnv"
                        },
                        {
                            "default": "tumor",
                            "id": "#main/loess_tumor/run_type"
                        },
                        {
                            "source": "#main/targets_coverage_annotation",
                            "id": "#main/loess_tumor/targets_coverage_annotation"
                        }
                    ],
                    "out": [
                        "#main/loess_tumor/loess_text",
                        "#main/loess_tumor/loess_pdf"
                    ],
                    "id": "#main/loess_tumor"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
